@@ -23,7 +23,10 @@
 #'     facet_wrap(~am)
 #' p + theme_igray()
 theme_igray <- function(base_size = 12, base_family = "") {
-  (theme_gray(base_size = base_size, base_family = base_family) + theme(rect = element_rect(fill = "gray90"), legend.key = element_rect(fill = "white"), 
-    panel.background = element_rect(fill = "white"), panel.grid.major = element_line(colour = "gray90"), plot.background = element_rect(fill = "gray90")))
+  (theme_gray(base_size = base_size, base_family = base_family) +
+     theme(rect = element_rect(fill = "gray90"),
+           legend.key = element_rect(fill = "white"),
+           panel.background = element_rect(fill = "white"),
+           panel.grid.major = element_line(colour = "gray90"),
+           plot.background = element_rect(fill = "gray90")))
 }
- 
